==> zio-aws-directconnect_2.12-5.17.158.3-sources.jar: zio/aws/directconnect/model/AcceptDirectConnectGatewayAssociationProposalResponse.scala <==
package zio.aws.directconnect.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AcceptDirectConnectGatewayAssociationProposalResponse(
    directConnectGatewayAssociation: Option[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse = {
    import AcceptDirectConnectGatewayAssociationProposalResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse
      .builder()
      .optionallyWith(
        directConnectGatewayAssociation.map(value => value.buildAwsValue())
      )(_.directConnectGatewayAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse.ReadOnly =
    zio.aws.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse
      .wrap(buildAwsValue())
}
object AcceptDirectConnectGatewayAssociationProposalResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse =
      zio.aws.directconnect.model
        .AcceptDirectConnectGatewayAssociationProposalResponse(
          directConnectGatewayAssociation.map(value => value.asEditable)
        )
    def directConnectGatewayAssociation: Option[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ]
    def getDirectConnectGatewayAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "directConnectGatewayAssociation",
      directConnectGatewayAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse
  ) extends zio.aws.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse.ReadOnly {
    override val directConnectGatewayAssociation: Option[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ] = scala
      .Option(impl.directConnectGatewayAssociation())
      .map(value =>
        zio.aws.directconnect.model.DirectConnectGatewayAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse
  ): zio.aws.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-directconnect_2.12-5.17.267.6-sources.jar: zio/aws/directconnect/model/AcceptDirectConnectGatewayAssociationProposalResponse.scala <==
package zio.aws.directconnect.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AcceptDirectConnectGatewayAssociationProposalResponse(
    directConnectGatewayAssociation: Optional[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse = {
    import AcceptDirectConnectGatewayAssociationProposalResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse
      .builder()
      .optionallyWith(
        directConnectGatewayAssociation.map(value => value.buildAwsValue())
      )(_.directConnectGatewayAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse.ReadOnly =
    zio.aws.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse
      .wrap(buildAwsValue())
}
object AcceptDirectConnectGatewayAssociationProposalResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse =
      zio.aws.directconnect.model
        .AcceptDirectConnectGatewayAssociationProposalResponse(
          directConnectGatewayAssociation.map(value => value.asEditable)
        )
    def directConnectGatewayAssociation: Optional[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ]
    def getDirectConnectGatewayAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "directConnectGatewayAssociation",
      directConnectGatewayAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse
  ) extends zio.aws.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse.ReadOnly {
    override val directConnectGatewayAssociation: Optional[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.directConnectGatewayAssociation())
      .map(value =>
        zio.aws.directconnect.model.DirectConnectGatewayAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse
  ): zio.aws.directconnect.model.AcceptDirectConnectGatewayAssociationProposalResponse.ReadOnly =
    new Wrapper(impl)
}
